yarpdataplayer_fix {#yarp_3_4}
 --------------------


 ### Tools

 #### `yarpdataplayer`
 

-  Fixed: [#2400:](https://github.com/robotology/yarp/issues/2400) yarpdataplayer --hidden cannot start on headless system
-  Fixed: [#2401:](https://github.com/robotology/yarp/issues/2401) yarpdataplayer closes immediately after loading data with --hidden flag is used
-  Fixed: [#2151:](https://github.com/robotology/yarp/issues/2151) step command in rpc exhibits odd behaviors
-  Fixed: [#2140:](https://github.com/robotology/yarp/issues/2140) Provide status flag to check if player has finished playing a loaded dataset
-  Fixed: [#1144:](https://github.com/robotology/yarp/issues/1144) yarpdataplayer enhancements

 #### `yarpdataplayer-console`

 * Created a dataplayer library to implement a console version of the yarpdataplayer to work without without X
